==> zeroc-ice_3.4.2.orig.tar.gz: Ice-3.4.2/cs/test/Glacier2/router/run.py <==
#!/usr/bin/env python
# **********************************************************************
#
# Copyright (c) 2003-2011 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************

import os, sys, getopt

path = [ ".", "..", "../..", "../../..", "../../../.." ]
head = os.path.dirname(sys.argv[0])
if len(head) > 0:
    path = [os.path.join(head, p) for p in path]
path = [os.path.abspath(p) for p in path if os.path.exists(os.path.join(p, "scripts", "TestUtil.py")) ]
if len(path) == 0:
    raise "can't find toplevel directory!"
sys.path.append(os.path.join(path[0]))
from scripts import *

router = os.path.join(TestUtil.getCppBinDir(), "glacier2router")

args = ' --Ice.Warn.Dispatch=0' + \
       ' --Ice.Warn.Connections=0' + \
       ' --Glacier2.Filter.Category.Accept="c1 c2"' + \
       ' --Glacier2.Filter.Category.AcceptUser="2"' + \
       ' --Glacier2.SessionTimeout="30"' + \
       ' --Glacier2.Client.Endpoints="default -p 12347"' + \
       ' --Glacier2.Server.Endpoints="tcp -h 127.0.0.1"' \
       ' --Ice.Admin.Endpoints="tcp -h 127.0.0.1 -p 12348"' + \
       ' --Ice.Admin.InstanceName=Glacier2' + \
       ' --Glacier2.CryptPasswords="' + os.path.join(os.getcwd(), "passwords") + '"'

print "starting router...",
routerConfig = TestUtil.DriverConfig("server")
routerConfig.lang = "cpp"
starterProc = TestUtil.startServer(router, args, count=2, config=routerConfig)
print "ok"

TestUtil.clientServerTest()

#
# We run the test again, to check whether the glacier router can
# handle multiple clients. Also, when we run for the second time, we
# want the client to shutdown the router after running the tests.
#
TestUtil.clientServerTest(additionalClientOptions=" --shutdown")

starterProc.waitTestSuccess()

==> zeroc-ice_3.5.1.orig.tar.gz: Ice-3.5.1/cs/test/Glacier2/router/run.py <==
#!/usr/bin/env python
# **********************************************************************
#
# Copyright (c) 2003-2013 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************

import os, sys, getopt

path = [ ".", "..", "../..", "../../..", "../../../.." ]
head = os.path.dirname(sys.argv[0])
if len(head) > 0:
    path = [os.path.join(head, p) for p in path]
path = [os.path.abspath(p) for p in path if os.path.exists(os.path.join(p, "scripts", "TestUtil.py")) ]
if len(path) == 0:
    raise RuntimeError("can't find toplevel directory!")
sys.path.append(os.path.join(path[0], "scripts"))
import TestUtil

router = os.path.join(TestUtil.getCppBinDir(), "glacier2router")

args = ' --Ice.Warn.Dispatch=0' + \
       ' --Ice.Warn.Connections=0' + \
       ' --Glacier2.Filter.Category.Accept="c1 c2"' + \
       ' --Glacier2.Filter.Category.AcceptUser="2"' + \
       ' --Glacier2.SessionTimeout="30"' + \
       ' --Glacier2.Client.Endpoints="default -p 12347"' + \
       ' --Glacier2.Server.Endpoints="tcp -h 127.0.0.1"' \
       ' --Ice.Admin.Endpoints="tcp -h 127.0.0.1 -p 12348"' + \
       ' --Ice.Admin.InstanceName=Glacier2' + \
       ' --Glacier2.CryptPasswords="' + os.path.join(os.getcwd(), "passwords") + '"'

sys.stdout.write("starting router... ")
sys.stdout.flush()
routerConfig = TestUtil.DriverConfig("server")
routerConfig.lang = "cpp"
starterProc = TestUtil.startServer(router, args, count=2, config=routerConfig)
print("ok")

TestUtil.clientServerTest()

#
# We run the test again, to check whether the glacier router can
# handle multiple clients. Also, when we run for the second time, we
# want the client to shutdown the router after running the tests.
#
TestUtil.clientServerTest(additionalClientOptions=" --shutdown")

starterProc.waitTestSuccess()
